@@ -604,29 +604,35 @@ class autoexport:
         os.system('cmd /c "{}"'.format(command))
 
     def run_process():
-        location = "C:\\Users\\Dell\\Documents\\Avirtech\\Avirkey"
+        location = os.path.expanduser('~/Documents/Avirtech/Avirkey')
         substring = "Avirkey.ini"
 
-        for file in os.listdir(location):
-            if file.find(substring) != -1:
-                autoexport.mycmd()
+        if os.path.isdir(location):
+            if len(os.listdir(location) ) == 1:
+                for file in os.listdir(location):
+                    if file.find(substring) != -1:
+                        autoexport.mycmd()
 
-                config = configparser.ConfigParser()
-                config.read("C:\\Users\\Dell\\Documents\\Avirtech\\Avirkey\\avirkey.ini")
+                        config = configparser.ConfigParser()
+                        config.read(os.path.expanduser('~/Documents/Avirtech/Avirkey/avirkey.ini'))
 
-                serial = config.get("SECURITY","Serial")
-                hashed_serial = config.get("SECURITY","Hash")
+                        serial = config.get("SECURITY","Serial")
+                        hashed_serial = config.get("SECURITY","Hash")
 
-                if serial is not None:
-                    if (hashed_serial == "BCED2A448DE179DD2940BD76AE29B4C2") or (hashed_serial == "77AD3616F9FDBFBA0FAE4A814ECA5D72") or (hashed_serial == "BBE292E1FE6A3CE9604A4B267A1F7822"):
-                        autoexport.declare_doc_metashape()
-                        autoexport.get_export_data()
-                        autoexport.processing_external_lib()
-                        autoexport.generating_auto_orthomosaic()
-                        autoexport.copy_report()
+                        if serial is not None:
+                            if (hashed_serial == "BCED2A448DE179DD2940BD76AE29B4C2") or (hashed_serial == "77AD3616F9FDBFBA0FAE4A814ECA5D72") or (hashed_serial == "BBE292E1FE6A3CE9604A4B267A1F7822"):
+                                autoexport.declare_doc_metashape()
+                                autoexport.get_export_data()
+                                autoexport.processing_external_lib()
+                                autoexport.generating_auto_orthomosaic()
+                                autoexport.copy_report()
+                            else:
+                                Metashape.app.messageBox("Wrong Credential Key, Cannot Continue Process")
                     else:
-                        Metashape.app.messageBox("Wrong Credential Key, Cannot Continue Process")
-                else:
-                    Metashape.app.messageBox("Please register your serial number on avirkey first!")
+                        Metashape.app.messageBox("Please register your serial number on avirkey first!")
+            elif len(os.listdir(location) ) == 0:
+                Metashape.app.messageBox("Cannot Run The Script, please register your hardware ID then input your serial number and run the script.")
             else:
-                Metashape.app.messageBox("Please install avirkey first, then generate your serial number and then run this script again")
\ No newline at end of file
+                Metashape.app.messageBox("Cannot Run The Script, please register your hardware ID then input your serial number and run the script.")
+        else:
+            Metashape.app.messageBox("Cannot Run The Script, Please install avirkey first, generate your serial number and then run this script again.")
\ No newline at end of file
